import OCP.IntAna
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.NCollection
import OCP.TColStd
import OCP.gp
__all__  = [
"IntAna_Curve",
"IntAna_Int3Pln",
"IntAna_IntConicQuad",
"IntAna_IntLinTorus",
"IntAna_IntQuadQuad",
"IntAna_ListOfCurve",
"IntAna_QuadQuadGeo",
"IntAna_Quadric",
"IntAna_ResultType",
"IntAna_Circle",
"IntAna_Ellipse",
"IntAna_Empty",
"IntAna_Hyperbola",
"IntAna_Line",
"IntAna_NoGeometricSolution",
"IntAna_Parabola",
"IntAna_Point",
"IntAna_PointAndCircle",
"IntAna_Same"
]
class IntAna_Curve():
    """
    Definition of a parametric Curve which is the result of the intersection between two quadrics.
    """
    def D1u(self,Theta : float,P : OCP.gp.gp_Pnt,V : OCP.gp.gp_Vec) -> bool: 
        """
        Returns the point and the first derivative at parameter Theta on the curve.
        """
    def Domain(self) -> tuple[float, float]: 
        """
        Returns the parametric domain of the curve.
        """
    def FindParameter(self,P : OCP.gp.gp_Pnt,theParams : OCP.TColStd.TColStd_ListOfReal) -> None: 
        """
        Tries to find the parameter of the point P on the curve. If the method returns False, the "projection" is impossible. If the method returns True at least one parameter has been found. theParams is always sorted in ascending order.
        """
    def IsConstant(self) -> bool: 
        """
        Returns TRUE if the function is constant.
        """
    def IsFirstOpen(self) -> bool: 
        """
        Returns TRUE if the domain is open at the beginning.
        """
    def IsLastOpen(self) -> bool: 
        """
        Returns TRUE if the domain is open at the end.
        """
    def IsOpen(self) -> bool: 
        """
        Returns TRUE if the curve is not infinite at the last parameter or at the first parameter of the domain.
        """
    def SetConeQuadValues(self,Cone : OCP.gp.gp_Cone,Qxx : float,Qyy : float,Qzz : float,Qxy : float,Qxz : float,Qyz : float,Qx : float,Qy : float,Qz : float,Q1 : float,Tol : float,DomInf : float,DomSup : float,TwoZForATheta : bool,ZIsPositive : bool) -> None: 
        """
        Sets the parameters used to compute Points and Derivative on the curve.
        """
    def SetCylinderQuadValues(self,Cylinder : OCP.gp.gp_Cylinder,Qxx : float,Qyy : float,Qzz : float,Qxy : float,Qxz : float,Qyz : float,Qx : float,Qy : float,Qz : float,Q1 : float,Tol : float,DomInf : float,DomSup : float,TwoZForATheta : bool,ZIsPositive : bool) -> None: 
        """
        Sets the parameters used to compute Points and Derivative on the curve.
        """
    def SetDomain(self,theFirst : float,theLast : float) -> None: 
        """
        Trims this curve
        """
    def SetIsFirstOpen(self,Flag : bool) -> None: 
        """
        If flag is True, the Curve is not defined at the first parameter of its domain.
        """
    def SetIsLastOpen(self,Flag : bool) -> None: 
        """
        If flag is True, the Curve is not defined at the first parameter of its domain.
        """
    def Value(self,Theta : float) -> OCP.gp.gp_Pnt: 
        """
        Returns the point at parameter Theta on the curve.
        """
    def __init__(self) -> None: ...
    pass
class IntAna_Int3Pln():
    """
    Intersection between 3 planes. The algorithm searches for an intersection point. If two of the planes are parallel or identical, IsEmpty returns TRUE.
    """
    def IsDone(self) -> bool: 
        """
        Returns True if the computation was successful.

        Returns True if the computation was successful.
        """
    def IsEmpty(self) -> bool: 
        """
        Returns TRUE if there is no intersection POINT. If 2 planes are identical or parallel, IsEmpty will return TRUE.

        Returns TRUE if there is no intersection POINT. If 2 planes are identical or parallel, IsEmpty will return TRUE.
        """
    def Perform(self,P1 : OCP.gp.gp_Pln,P2 : OCP.gp.gp_Pln,P3 : OCP.gp.gp_Pln) -> None: 
        """
        Determination of the intersection point between 3 planes.
        """
    def Value(self) -> OCP.gp.gp_Pnt: 
        """
        Returns the intersection point.

        Returns the intersection point.
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,P1 : OCP.gp.gp_Pln,P2 : OCP.gp.gp_Pln,P3 : OCP.gp.gp_Pln) -> None: ...
    pass
class IntAna_IntConicQuad():
    """
    This class provides the analytic intersection between a conic defined as an element of gp (Lin,Circ,Elips, Parab,Hypr) and a quadric as defined in the class Quadric from IntAna. The intersection between a conic and a plane is treated as a special case.
    """
    def IsDone(self) -> bool: 
        """
        Returns TRUE if the creation completed.

        Returns TRUE if the creation completed.
        """
    def IsInQuadric(self) -> bool: 
        """
        Returns TRUE if the conic is in the quadric.

        Returns TRUE if the conic is in the quadric.
        """
    def IsParallel(self) -> bool: 
        """
        Returns TRUE if the line is in a quadric which is parallel to the quadric.

        Returns TRUE if the line is in a quadric which is parallel to the quadric.
        """
    def NbPoints(self) -> int: 
        """
        Returns the number of intersection point.

        Returns the number of intersection point.
        """
    @overload
    def ParamOnConic(self,N : int) -> float: 
        """
        Returns the parameter on the line of the intersection point of range N.

        Returns the parameter on the line of the intersection point of range N.
        """
    @overload
    def ParamOnConic(self,i : int) -> float: ...
    @overload
    def Perform(self,L : OCP.gp.gp_Lin,Q : IntAna_Quadric) -> None: 
        """
        Intersects a line and a quadric.

        Intersects a circle and a quadric.

        Intersects an ellipse and a quadric.

        Intersects a parabola and a quadric.

        Intersects an hyperbola and a quadric.

        Intersects a line and a plane. Tolang is used to determine if the angle between two vectors is null. Tol is used to check the distance between line and plane on the distance <Len> from the origin of the line.

        Intersects a circle and a plane. Tolang is used to determine if the angle between two vectors is null. Tol is used to determine if a distance is null.

        Intersects an ellipse and a plane. Tolang is used to determine if the angle between two vectors is null. Tol is used to determine if a distance is null.

        Intersects a parabola and a plane. Tolang is used to determine if the angle between two vectors is null.

        Intersects an hyperbola and a plane. Tolang is used to determine if the angle between two vectors is null.
        """
    @overload
    def Perform(self,C : OCP.gp.gp_Circ,Q : IntAna_Quadric) -> None: ...
    @overload
    def Perform(self,E : OCP.gp.gp_Elips,Q : IntAna_Quadric) -> None: ...
    @overload
    def Perform(self,P : OCP.gp.gp_Parab,Q : IntAna_Quadric) -> None: ...
    @overload
    def Perform(self,H : OCP.gp.gp_Hypr,Q : IntAna_Quadric) -> None: ...
    @overload
    def Perform(self,L : OCP.gp.gp_Lin,P : OCP.gp.gp_Pln,Tolang : float,Tol : float=0.0,Len : float=0.0) -> None: ...
    @overload
    def Perform(self,C : OCP.gp.gp_Circ,P : OCP.gp.gp_Pln,Tolang : float,Tol : float) -> None: ...
    @overload
    def Perform(self,E : OCP.gp.gp_Elips,P : OCP.gp.gp_Pln,Tolang : float,Tol : float) -> None: ...
    @overload
    def Perform(self,Pb : OCP.gp.gp_Parab,P : OCP.gp.gp_Pln,Tolang : float) -> None: ...
    @overload
    def Perform(self,H : OCP.gp.gp_Hypr,P : OCP.gp.gp_Pln,Tolang : float) -> None: ...
    @overload
    def Point(self,N : int) -> OCP.gp.gp_Pnt: 
        """
        Returns the point of range N.

        Returns the point of range N.
        """
    @overload
    def Point(self,i : int) -> OCP.gp.gp_Pnt: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,L : OCP.gp.gp_Lin,Q : IntAna_Quadric) -> None: ...
    @overload
    def __init__(self,C : OCP.gp.gp_Circ,Q : IntAna_Quadric) -> None: ...
    @overload
    def __init__(self,E : OCP.gp.gp_Elips,Q : IntAna_Quadric) -> None: ...
    @overload
    def __init__(self,P : OCP.gp.gp_Parab,Q : IntAna_Quadric) -> None: ...
    @overload
    def __init__(self,H : OCP.gp.gp_Hypr,Q : IntAna_Quadric) -> None: ...
    @overload
    def __init__(self,L : OCP.gp.gp_Lin,P : OCP.gp.gp_Pln,Tolang : float,Tol : float=0.0,Len : float=0.0) -> None: ...
    @overload
    def __init__(self,C : OCP.gp.gp_Circ,P : OCP.gp.gp_Pln,Tolang : float,Tol : float) -> None: ...
    @overload
    def __init__(self,E : OCP.gp.gp_Elips,P : OCP.gp.gp_Pln,Tolang : float,Tol : float) -> None: ...
    @overload
    def __init__(self,Pb : OCP.gp.gp_Parab,P : OCP.gp.gp_Pln,Tolang : float) -> None: ...
    @overload
    def __init__(self,H : OCP.gp.gp_Hypr,P : OCP.gp.gp_Pln,Tolang : float) -> None: ...
    pass
class IntAna_IntLinTorus():
    """
    Intersection between a line and a torus.
    """
    def IsDone(self) -> bool: 
        """
        Returns True if the computation was successful.

        Returns True if the computation was successful.
        """
    def NbPoints(self) -> int: 
        """
        Returns the number of intersection points.

        Returns the number of intersection points.
        """
    def ParamOnLine(self,Index : int) -> float: 
        """
        Returns the parameter on the line of the intersection point of range Index.

        Returns the parameter on the line of the intersection point of range Index.
        """
    def ParamOnTorus(self,Index : int) -> tuple[float, float]: 
        """
        Returns the parameters on the torus of the intersection point of range Index.

        Returns the parameters on the torus of the intersection point of range Index.
        """
    def Perform(self,L : OCP.gp.gp_Lin,T : OCP.gp.gp_Torus) -> None: 
        """
        Intersects a line and a torus.
        """
    def Value(self,Index : int) -> OCP.gp.gp_Pnt: 
        """
        Returns the intersection point of range Index.

        Returns the intersection point of range Index.
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,L : OCP.gp.gp_Lin,T : OCP.gp.gp_Torus) -> None: ...
    pass
class IntAna_IntQuadQuad():
    """
    This class provides the analytic intersection between a cylinder or a cone from gp and another quadric, as defined in the class Quadric from IntAna. This algorithm is used when the geometric intersection (class QuadQuadGeo from IntAna) returns no geometric solution. The result of the intersection may be - Curves as defined in the class Curve from IntAna - Points (Pnt from gp)
    """
    def Curve(self,N : int) -> IntAna_Curve: 
        """
        Returns the curve of range N.
        """
    def HasNextCurve(self,I : int) -> bool: 
        """
        Returns True if the Curve I shares its last bound with another curve.
        """
    def HasPreviousCurve(self,I : int) -> bool: 
        """
        Returns True if the Curve I shares its first bound with another curve.
        """
    def IdenticalElements(self) -> bool: 
        """
        Returns TRUE if the cylinder, the cone or the sphere is identical to the quadric.

        Returns TRUE if the cylinder, the cone or the sphere is identical to the quadric.
        """
    def IsDone(self) -> bool: 
        """
        Returns True if the computation was successful.

        Returns True if the computation was successful.
        """
    def NbCurve(self) -> int: 
        """
        Returns the number of curves solution.

        Returns the number of curves solution.
        """
    def NbPnt(self) -> int: 
        """
        Returns the number of contact point.

        Returns the number of contact point.
        """
    def NextCurve(self,I : int,theOpposite : bool) -> int: 
        """
        If HasNextCurve(I) returns True, this function returns the Index J of the curve which has a common bound with the curve I. If theOpposite == True , then the last parameter of the curve I, and the last parameter of the curve J give the same point. Else the last parameter of the curve I and the first parameter of the curve J are the same point.
        """
    def Parameters(self,N : int) -> tuple[float, float]: 
        """
        Returns the parameters on the "explicit quadric" (i.e the cylinder or the cone, the first argument given to the constructor) of the point of range N.
        """
    @overload
    def Perform(self,C : OCP.gp.gp_Cylinder,Q : IntAna_Quadric,Tol : float) -> None: 
        """
        Intersects a cylinder and a quadric . Tol est a definir plus precisemment.

        Intersects a cone and a quadric. Tol est a definir plus precisemment.
        """
    @overload
    def Perform(self,C : OCP.gp.gp_Cone,Q : IntAna_Quadric,Tol : float) -> None: ...
    def Point(self,N : int) -> OCP.gp.gp_Pnt: 
        """
        Returns the point of range N.
        """
    def PreviousCurve(self,I : int,theOpposite : bool) -> int: 
        """
        if HasPreviousCurve(I) returns True, this function returns the Index J of the curve which has a common bound with the curve I. If theOpposite == True , then the first parameter of the curve I, and the first parameter of the curve J give the same point. Else the first parameter of the curve I and the last parameter of the curve J are the same point.
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,C : OCP.gp.gp_Cylinder,Q : IntAna_Quadric,Tol : float) -> None: ...
    @overload
    def __init__(self,C : OCP.gp.gp_Cone,Q : IntAna_Quadric,Tol : float) -> None: ...
    pass
class IntAna_ListOfCurve(OCP.NCollection.NCollection_BaseList):
    """
    Purpose: Simple list to link items together keeping the first and the last one. Inherits BaseList, adding the data item to each node.
    """
    def Allocator(self) -> OCP.NCollection.NCollection_BaseAllocator: 
        """
        Returns attached allocator
        """
    @overload
    def Append(self,theItem : IntAna_Curve) -> IntAna_Curve: 
        """
        Append one item at the end

        Append one item at the end and output iterator pointing at the appended item

        Append another list at the end. After this operation, theOther list will be cleared.
        """
    @overload
    def Append(self,theItem : IntAna_Curve,theIter : Any) -> None: ...
    @overload
    def Append(self,theOther : IntAna_ListOfCurve) -> None: ...
    def Assign(self,theOther : IntAna_ListOfCurve) -> IntAna_ListOfCurve: 
        """
        Replace this list by the items of another list (theOther parameter). This method does not change the internal allocator.
        """
    def Clear(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator=None) -> None: 
        """
        Clear this list
        """
    def Extent(self) -> int: ...
    def First(self) -> IntAna_Curve: 
        """
        First item

        First item (non-const)
        """
    @overload
    def InsertAfter(self,theItem : IntAna_Curve,theIter : Any) -> IntAna_Curve: 
        """
        InsertAfter

        InsertAfter
        """
    @overload
    def InsertAfter(self,theOther : IntAna_ListOfCurve,theIter : Any) -> None: ...
    @overload
    def InsertBefore(self,theItem : IntAna_Curve,theIter : Any) -> IntAna_Curve: 
        """
        InsertBefore

        InsertBefore
        """
    @overload
    def InsertBefore(self,theOther : IntAna_ListOfCurve,theIter : Any) -> None: ...
    def IsEmpty(self) -> bool: ...
    def Last(self) -> IntAna_Curve: 
        """
        Last item

        Last item (non-const)
        """
    @overload
    def Prepend(self,theItem : IntAna_Curve) -> IntAna_Curve: 
        """
        Prepend one item at the beginning

        Prepend another list at the beginning
        """
    @overload
    def Prepend(self,theOther : IntAna_ListOfCurve) -> None: ...
    def Remove(self,theIter : Any) -> None: 
        """
        Remove item pointed by iterator theIter; theIter is then set to the next item
        """
    def RemoveFirst(self) -> None: 
        """
        RemoveFirst item
        """
    def Reverse(self) -> None: 
        """
        Reverse the list
        """
    def Size(self) -> int: 
        """
        Size - Number of items
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator) -> None: ...
    @overload
    def __init__(self,theOther : IntAna_ListOfCurve) -> None: ...
    def __iter__(self) -> Iterator[IntAna_Curve]: ...
    def __len__(self) -> int: ...
    pass
class IntAna_QuadQuadGeo():
    """
    Geometric intersections between two natural quadrics (Sphere , Cylinder , Cone , Pln from gp). The possible intersections are : - 1 point - 1 or 2 line(s) - 1 Point and 1 Line - 1 circle - 1 ellipse - 1 parabola - 1 or 2 hyperbola(s). - Empty : there is no intersection between the two quadrics. - Same : the quadrics are identical - NoGeometricSolution : there may be an intersection, but it is necessary to use an analytic algorithm to determine it. See class IntQuadQuad from IntAna.
    """
    def Circle(self,Num : int) -> OCP.gp.gp_Circ: 
        """
        Returns the circle solution of range Num.
        """
    def Ellipse(self,Num : int) -> OCP.gp.gp_Elips: 
        """
        Returns the ellipse solution of range Num.
        """
    def HasCommonGen(self) -> bool: ...
    def Hyperbola(self,Num : int) -> OCP.gp.gp_Hypr: 
        """
        Returns the hyperbola solution of range Num.
        """
    def IsDone(self) -> bool: 
        """
        Returns Standard_True if the computation was successful.

        Returns Standard_True if the computation was successful.
        """
    def Line(self,Num : int) -> OCP.gp.gp_Lin: 
        """
        Returns the line solution of range Num.
        """
    def NbSolutions(self) -> int: 
        """
        Returns the number of intersections. The possible intersections are : - 1 point - 1 or 2 line(s) - 1 Point and 1 Line - 1 circle - 1 ellipse - 1 parabola - 1 or 2 hyperbola(s).

        Returns the number of intersections. The possible intersections are : - 1 point - 1 or 2 line(s) - 1 Point and 1 Line - 1 circle - 1 ellipse - 1 parabola - 1 or 2 hyperbola(s).
        """
    def PChar(self) -> OCP.gp.gp_Pnt: ...
    def Parabola(self,Num : int) -> OCP.gp.gp_Parab: 
        """
        Returns the parabola solution of range Num.
        """
    @overload
    def Perform(self,P1 : OCP.gp.gp_Pln,P2 : OCP.gp.gp_Pln,TolAng : float,Tol : float) -> None: 
        """
        Intersects two planes. TolAng is the angular tolerance used to determine if the planes are parallel. Tol is the tolerance used to determine if the planes are identical (only when they are parallel).

        Intersects a plane and a cylinder. TolAng is the angular tolerance used to determine if the axis of the cylinder is parallel to the plane. Tol is the tolerance used to determine if the result is a circle or an ellipse. If the maximum distance between the ellipse solution and the circle centered at the ellipse center is less than Tol, the result will be the circle. H is the height of the cylinder <Cyl>. It is used to check whether the plane and cylinder are parallel.

        Intersects a plane and a sphere.

        Intersects a plane and a cone. TolAng is the angular tolerance used to determine if the axis of the cone is parallel or perpendicular to the plane, and if the generating line of the cone is parallel to the plane. Tol is the tolerance used to determine if the apex of the cone is in the plane.

        Intersects two cylinders

        Intersects a cylinder and a sphere.

        Intersects a cylinder and a cone.

        Intersects a two spheres.

        Intersects a sphere and a cone.

        Intersects two cones.

        Intersects plane and torus.

        Intersects cylinder and torus.

        Intersects cone and torus.

        Intersects sphere and torus.

        Intersects two toruses.
        """
    @overload
    def Perform(self,P : OCP.gp.gp_Pln,C : OCP.gp.gp_Cylinder,Tolang : float,Tol : float,H : float=0.0) -> None: ...
    @overload
    def Perform(self,P : OCP.gp.gp_Pln,S : OCP.gp.gp_Sphere) -> None: ...
    @overload
    def Perform(self,P : OCP.gp.gp_Pln,C : OCP.gp.gp_Cone,Tolang : float,Tol : float) -> None: ...
    @overload
    def Perform(self,Cyl1 : OCP.gp.gp_Cylinder,Cyl2 : OCP.gp.gp_Cylinder,Tol : float) -> None: ...
    @overload
    def Perform(self,Cyl : OCP.gp.gp_Cylinder,Sph : OCP.gp.gp_Sphere,Tol : float) -> None: ...
    @overload
    def Perform(self,Cyl : OCP.gp.gp_Cylinder,Con : OCP.gp.gp_Cone,Tol : float) -> None: ...
    @overload
    def Perform(self,Sph1 : OCP.gp.gp_Sphere,Sph2 : OCP.gp.gp_Sphere,Tol : float) -> None: ...
    @overload
    def Perform(self,Sph : OCP.gp.gp_Sphere,Con : OCP.gp.gp_Cone,Tol : float) -> None: ...
    @overload
    def Perform(self,Con1 : OCP.gp.gp_Cone,Con2 : OCP.gp.gp_Cone,Tol : float) -> None: ...
    @overload
    def Perform(self,Pln : OCP.gp.gp_Pln,Tor : OCP.gp.gp_Torus,Tol : float) -> None: ...
    @overload
    def Perform(self,Cyl : OCP.gp.gp_Cylinder,Tor : OCP.gp.gp_Torus,Tol : float) -> None: ...
    @overload
    def Perform(self,Con : OCP.gp.gp_Cone,Tor : OCP.gp.gp_Torus,Tol : float) -> None: ...
    @overload
    def Perform(self,Sph : OCP.gp.gp_Sphere,Tor : OCP.gp.gp_Torus,Tol : float) -> None: ...
    @overload
    def Perform(self,Tor1 : OCP.gp.gp_Torus,Tor2 : OCP.gp.gp_Torus,Tol : float) -> None: ...
    def Point(self,Num : int) -> OCP.gp.gp_Pnt: 
        """
        Returns the point solution of range Num.
        """
    def TypeInter(self) -> IntAna_ResultType: 
        """
        Returns the type of intersection.

        Returns the type of intersection.
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,P1 : OCP.gp.gp_Pln,P2 : OCP.gp.gp_Pln,TolAng : float,Tol : float) -> None: ...
    @overload
    def __init__(self,P : OCP.gp.gp_Pln,C : OCP.gp.gp_Cylinder,Tolang : float,Tol : float,H : float=0.0) -> None: ...
    @overload
    def __init__(self,P : OCP.gp.gp_Pln,S : OCP.gp.gp_Sphere) -> None: ...
    @overload
    def __init__(self,P : OCP.gp.gp_Pln,C : OCP.gp.gp_Cone,Tolang : float,Tol : float) -> None: ...
    @overload
    def __init__(self,Cyl1 : OCP.gp.gp_Cylinder,Cyl2 : OCP.gp.gp_Cylinder,Tol : float) -> None: ...
    @overload
    def __init__(self,Cyl : OCP.gp.gp_Cylinder,Sph : OCP.gp.gp_Sphere,Tol : float) -> None: ...
    @overload
    def __init__(self,Cyl : OCP.gp.gp_Cylinder,Con : OCP.gp.gp_Cone,Tol : float) -> None: ...
    @overload
    def __init__(self,Sph1 : OCP.gp.gp_Sphere,Sph2 : OCP.gp.gp_Sphere,Tol : float) -> None: ...
    @overload
    def __init__(self,Sph : OCP.gp.gp_Sphere,Con : OCP.gp.gp_Cone,Tol : float) -> None: ...
    @overload
    def __init__(self,Con1 : OCP.gp.gp_Cone,Con2 : OCP.gp.gp_Cone,Tol : float) -> None: ...
    @overload
    def __init__(self,Pln : OCP.gp.gp_Pln,Tor : OCP.gp.gp_Torus,Tol : float) -> None: ...
    @overload
    def __init__(self,Cyl : OCP.gp.gp_Cylinder,Tor : OCP.gp.gp_Torus,Tol : float) -> None: ...
    @overload
    def __init__(self,Con : OCP.gp.gp_Cone,Tor : OCP.gp.gp_Torus,Tol : float) -> None: ...
    @overload
    def __init__(self,Sph : OCP.gp.gp_Sphere,Tor : OCP.gp.gp_Torus,Tol : float) -> None: ...
    @overload
    def __init__(self,Tor1 : OCP.gp.gp_Torus,Tor2 : OCP.gp.gp_Torus,Tol : float) -> None: ...
    pass
class IntAna_Quadric():
    """
    This class provides a description of Quadrics by their Coefficients in natural coordinate system.
    """
    def Coefficients(self) -> tuple[float, float, float, float, float, float, float, float, float, float]: 
        """
        Returns the coefficients of the polynomial equation which define the quadric: xCXX x**2 + xCYY y**2 + xCZZ z**2 + 2 ( xCXY x y + xCXZ x z + xCYZ y z ) + 2 ( xCX x + xCY y + xCZ z ) + xCCte
        """
    def NewCoefficients(self,Axis : OCP.gp.gp_Ax3) -> tuple[float, float, float, float, float, float, float, float, float, float]: 
        """
        Returns the coefficients of the polynomial equation ( written in the natural coordinates system ) in the local coordinates system defined by Axis
        """
    @overload
    def SetQuadric(self,P : OCP.gp.gp_Pln) -> None: 
        """
        Initializes the quadric with a Pln

        Initialize the quadric with a Sphere

        Initializes the quadric with a Cone

        Initializes the quadric with a Cylinder
        """
    @overload
    def SetQuadric(self,Sph : OCP.gp.gp_Sphere) -> None: ...
    @overload
    def SetQuadric(self,Con : OCP.gp.gp_Cone) -> None: ...
    @overload
    def SetQuadric(self,Cyl : OCP.gp.gp_Cylinder) -> None: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,P : OCP.gp.gp_Pln) -> None: ...
    @overload
    def __init__(self,Sph : OCP.gp.gp_Sphere) -> None: ...
    @overload
    def __init__(self,Cyl : OCP.gp.gp_Cylinder) -> None: ...
    @overload
    def __init__(self,Cone : OCP.gp.gp_Cone) -> None: ...
    pass
class IntAna_ResultType():
    """
    Members:

      IntAna_Point

      IntAna_Line

      IntAna_Circle

      IntAna_PointAndCircle

      IntAna_Ellipse

      IntAna_Parabola

      IntAna_Hyperbola

      IntAna_Empty

      IntAna_Same

      IntAna_NoGeometricSolution
    """
    def __eq__(self,other : object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __init__(self,value : int) -> None: ...
    def __int__(self) -> int: ...
    def __ne__(self,other : object) -> bool: ...
    def __repr__(self) -> str: ...
    def __setstate__(self,state : int) -> None: ...
    def __str__(self) -> str: ...
    @property
    def name(self) -> None:
        """
        :type: None
        """
    @property
    def value(self) -> int:
        """
        :type: int
        """
    IntAna_Circle: OCP.IntAna.IntAna_ResultType # value = <IntAna_ResultType.IntAna_Circle: 2>
    IntAna_Ellipse: OCP.IntAna.IntAna_ResultType # value = <IntAna_ResultType.IntAna_Ellipse: 4>
    IntAna_Empty: OCP.IntAna.IntAna_ResultType # value = <IntAna_ResultType.IntAna_Empty: 7>
    IntAna_Hyperbola: OCP.IntAna.IntAna_ResultType # value = <IntAna_ResultType.IntAna_Hyperbola: 6>
    IntAna_Line: OCP.IntAna.IntAna_ResultType # value = <IntAna_ResultType.IntAna_Line: 1>
    IntAna_NoGeometricSolution: OCP.IntAna.IntAna_ResultType # value = <IntAna_ResultType.IntAna_NoGeometricSolution: 9>
    IntAna_Parabola: OCP.IntAna.IntAna_ResultType # value = <IntAna_ResultType.IntAna_Parabola: 5>
    IntAna_Point: OCP.IntAna.IntAna_ResultType # value = <IntAna_ResultType.IntAna_Point: 0>
    IntAna_PointAndCircle: OCP.IntAna.IntAna_ResultType # value = <IntAna_ResultType.IntAna_PointAndCircle: 3>
    IntAna_Same: OCP.IntAna.IntAna_ResultType # value = <IntAna_ResultType.IntAna_Same: 8>
    __entries: dict # value = {'IntAna_Point': (<IntAna_ResultType.IntAna_Point: 0>, None), 'IntAna_Line': (<IntAna_ResultType.IntAna_Line: 1>, None), 'IntAna_Circle': (<IntAna_ResultType.IntAna_Circle: 2>, None), 'IntAna_PointAndCircle': (<IntAna_ResultType.IntAna_PointAndCircle: 3>, None), 'IntAna_Ellipse': (<IntAna_ResultType.IntAna_Ellipse: 4>, None), 'IntAna_Parabola': (<IntAna_ResultType.IntAna_Parabola: 5>, None), 'IntAna_Hyperbola': (<IntAna_ResultType.IntAna_Hyperbola: 6>, None), 'IntAna_Empty': (<IntAna_ResultType.IntAna_Empty: 7>, None), 'IntAna_Same': (<IntAna_ResultType.IntAna_Same: 8>, None), 'IntAna_NoGeometricSolution': (<IntAna_ResultType.IntAna_NoGeometricSolution: 9>, None)}
    __members__: dict # value = {'IntAna_Point': <IntAna_ResultType.IntAna_Point: 0>, 'IntAna_Line': <IntAna_ResultType.IntAna_Line: 1>, 'IntAna_Circle': <IntAna_ResultType.IntAna_Circle: 2>, 'IntAna_PointAndCircle': <IntAna_ResultType.IntAna_PointAndCircle: 3>, 'IntAna_Ellipse': <IntAna_ResultType.IntAna_Ellipse: 4>, 'IntAna_Parabola': <IntAna_ResultType.IntAna_Parabola: 5>, 'IntAna_Hyperbola': <IntAna_ResultType.IntAna_Hyperbola: 6>, 'IntAna_Empty': <IntAna_ResultType.IntAna_Empty: 7>, 'IntAna_Same': <IntAna_ResultType.IntAna_Same: 8>, 'IntAna_NoGeometricSolution': <IntAna_ResultType.IntAna_NoGeometricSolution: 9>}
    pass
IntAna_Circle: OCP.IntAna.IntAna_ResultType # value = <IntAna_ResultType.IntAna_Circle: 2>
IntAna_Ellipse: OCP.IntAna.IntAna_ResultType # value = <IntAna_ResultType.IntAna_Ellipse: 4>
IntAna_Empty: OCP.IntAna.IntAna_ResultType # value = <IntAna_ResultType.IntAna_Empty: 7>
IntAna_Hyperbola: OCP.IntAna.IntAna_ResultType # value = <IntAna_ResultType.IntAna_Hyperbola: 6>
IntAna_Line: OCP.IntAna.IntAna_ResultType # value = <IntAna_ResultType.IntAna_Line: 1>
IntAna_NoGeometricSolution: OCP.IntAna.IntAna_ResultType # value = <IntAna_ResultType.IntAna_NoGeometricSolution: 9>
IntAna_Parabola: OCP.IntAna.IntAna_ResultType # value = <IntAna_ResultType.IntAna_Parabola: 5>
IntAna_Point: OCP.IntAna.IntAna_ResultType # value = <IntAna_ResultType.IntAna_Point: 0>
IntAna_PointAndCircle: OCP.IntAna.IntAna_ResultType # value = <IntAna_ResultType.IntAna_PointAndCircle: 3>
IntAna_Same: OCP.IntAna.IntAna_ResultType # value = <IntAna_ResultType.IntAna_Same: 8>



import OCP.XCAFNoteObjects
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.Standard
import OCP.TopoDS
import OCP.gp
__all__  = [
"XCAFNoteObjects_NoteObject"
]
class XCAFNoteObjects_NoteObject(OCP.Standard.Standard_Transient):
    """
    object to store note auxiliary dataobject to store note auxiliary data
    """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetPlane(self) -> OCP.gp.gp_Ax2: 
        """
        Returns a right-handed coordinate system of the plane
        """
    def GetPoint(self) -> OCP.gp.gp_Pnt: 
        """
        Returns the attachment point on the annotated object
        """
    def GetPointText(self) -> OCP.gp.gp_Pnt: 
        """
        Returns the text position
        """
    def GetPresentation(self) -> OCP.TopoDS.TopoDS_Shape: 
        """
        Returns a tessellated annotation if specified
        """
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def HasPlane(self) -> bool: 
        """
        Returns True if plane is specified
        """
    def HasPoint(self) -> bool: 
        """
        Returns True if the attachment point on the annotated object is specified
        """
    def HasPointText(self) -> bool: 
        """
        Returns True if the text position is specified
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def Reset(self) -> None: 
        """
        Resets data to the state after calling the default constructor
        """
    def SetPlane(self,thePlane : OCP.gp.gp_Ax2) -> None: 
        """
        Sets a right-handed coordinate system of the plane
        """
    def SetPoint(self,thePnt : OCP.gp.gp_Pnt) -> None: 
        """
        Sets the anchor point on the annotated object
        """
    def SetPointText(self,thePnt : OCP.gp.gp_Pnt) -> None: 
        """
        Sets the text position
        """
    def SetPresentation(self,thePresentation : OCP.TopoDS.TopoDS_Shape) -> None: 
        """
        Sets a tessellated annotation
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theObj : XCAFNoteObjects_NoteObject) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass



import OCP.Resource
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.TCollection
import io
import OCP.NCollection
import OCP.Standard
__all__  = [
"Resource_DataMapOfAsciiStringAsciiString",
"Resource_DataMapOfAsciiStringExtendedString",
"Resource_FormatType",
"Resource_LexicalCompare",
"Resource_Manager",
"Resource_Unicode",
"Resource_ANSI",
"Resource_EUC",
"Resource_FormatType_ANSI",
"Resource_FormatType_Big5",
"Resource_FormatType_CP1250",
"Resource_FormatType_CP1251",
"Resource_FormatType_CP1252",
"Resource_FormatType_CP1253",
"Resource_FormatType_CP1254",
"Resource_FormatType_CP1255",
"Resource_FormatType_CP1256",
"Resource_FormatType_CP1257",
"Resource_FormatType_CP1258",
"Resource_FormatType_CP850",
"Resource_FormatType_EUC",
"Resource_FormatType_GB",
"Resource_FormatType_GBK",
"Resource_FormatType_NoConversion",
"Resource_FormatType_SJIS",
"Resource_FormatType_SystemLocale",
"Resource_FormatType_UTF8",
"Resource_FormatType_iso8859_1",
"Resource_FormatType_iso8859_2",
"Resource_FormatType_iso8859_3",
"Resource_FormatType_iso8859_4",
"Resource_FormatType_iso8859_5",
"Resource_FormatType_iso8859_6",
"Resource_FormatType_iso8859_7",
"Resource_FormatType_iso8859_8",
"Resource_FormatType_iso8859_9",
"Resource_GB",
"Resource_SJIS"
]
class Resource_DataMapOfAsciiStringAsciiString(OCP.NCollection.NCollection_BaseMap):
    """
    Purpose: The DataMap is a Map to store keys with associated Items. See Map from NCollection for a discussion about the number of buckets.
    """
    def Allocator(self) -> OCP.NCollection.NCollection_BaseAllocator: 
        """
        Returns attached allocator
        """
    def Assign(self,theOther : Resource_DataMapOfAsciiStringAsciiString) -> Resource_DataMapOfAsciiStringAsciiString: 
        """
        Assignment. This method does not change the internal allocator.
        """
    def Bind(self,theKey : OCP.TCollection.TCollection_AsciiString,theItem : OCP.TCollection.TCollection_AsciiString) -> bool: 
        """
        Bind binds Item to Key in map.
        """
    def Bound(self,theKey : OCP.TCollection.TCollection_AsciiString,theItem : OCP.TCollection.TCollection_AsciiString) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Bound binds Item to Key in map.
        """
    def ChangeFind(self,theKey : OCP.TCollection.TCollection_AsciiString) -> OCP.TCollection.TCollection_AsciiString: 
        """
        ChangeFind returns mofifiable Item by Key. Raises if Key was not bound
        """
    def ChangeSeek(self,theKey : OCP.TCollection.TCollection_AsciiString) -> OCP.TCollection.TCollection_AsciiString: 
        """
        ChangeSeek returns modifiable pointer to Item by Key. Returns NULL is Key was not bound.
        """
    @overload
    def Clear(self,doReleaseMemory : bool=False) -> None: 
        """
        Clear data. If doReleaseMemory is false then the table of buckets is not released and will be reused.

        Clear data and reset allocator
        """
    @overload
    def Clear(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator) -> None: ...
    def Exchange(self,theOther : Resource_DataMapOfAsciiStringAsciiString) -> None: 
        """
        Exchange the content of two maps without re-allocations. Notice that allocators will be swapped as well!
        """
    def Extent(self) -> int: 
        """
        Extent
        """
    @overload
    def Find(self,theKey : OCP.TCollection.TCollection_AsciiString) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Find returns the Item for Key. Raises if Key was not bound

        Find Item for key with copying.
        """
    @overload
    def Find(self,theKey : OCP.TCollection.TCollection_AsciiString,theValue : OCP.TCollection.TCollection_AsciiString) -> bool: ...
    def IsBound(self,theKey : OCP.TCollection.TCollection_AsciiString) -> bool: 
        """
        IsBound
        """
    def IsEmpty(self) -> bool: 
        """
        IsEmpty
        """
    def NbBuckets(self) -> int: 
        """
        NbBuckets
        """
    def ReSize(self,N : int) -> None: 
        """
        ReSize
        """
    def Seek(self,theKey : OCP.TCollection.TCollection_AsciiString) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Seek returns pointer to Item by Key. Returns NULL is Key was not bound.
        """
    def Size(self) -> int: 
        """
        Size
        """
    def Statistics(self,S : io.BytesIO) -> None: 
        """
        Statistics
        """
    def UnBind(self,theKey : OCP.TCollection.TCollection_AsciiString) -> bool: 
        """
        UnBind removes Item Key pair from map
        """
    def __call__(self,theKey : OCP.TCollection.TCollection_AsciiString) -> OCP.TCollection.TCollection_AsciiString: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theNbBuckets : int,theAllocator : OCP.NCollection.NCollection_BaseAllocator=None) -> None: ...
    @overload
    def __init__(self,theOther : Resource_DataMapOfAsciiStringAsciiString) -> None: ...
    def __iter__(self) -> Iterator[OCP.TCollection.TCollection_AsciiString]: ...
    def __len__(self) -> int: ...
    pass
class Resource_DataMapOfAsciiStringExtendedString(OCP.NCollection.NCollection_BaseMap):
    """
    Purpose: The DataMap is a Map to store keys with associated Items. See Map from NCollection for a discussion about the number of buckets.
    """
    def Allocator(self) -> OCP.NCollection.NCollection_BaseAllocator: 
        """
        Returns attached allocator
        """
    def Assign(self,theOther : Resource_DataMapOfAsciiStringExtendedString) -> Resource_DataMapOfAsciiStringExtendedString: 
        """
        Assignment. This method does not change the internal allocator.
        """
    def Bind(self,theKey : OCP.TCollection.TCollection_AsciiString,theItem : OCP.TCollection.TCollection_ExtendedString) -> bool: 
        """
        Bind binds Item to Key in map.
        """
    def Bound(self,theKey : OCP.TCollection.TCollection_AsciiString,theItem : OCP.TCollection.TCollection_ExtendedString) -> OCP.TCollection.TCollection_ExtendedString: 
        """
        Bound binds Item to Key in map.
        """
    def ChangeFind(self,theKey : OCP.TCollection.TCollection_AsciiString) -> OCP.TCollection.TCollection_ExtendedString: 
        """
        ChangeFind returns mofifiable Item by Key. Raises if Key was not bound
        """
    def ChangeSeek(self,theKey : OCP.TCollection.TCollection_AsciiString) -> OCP.TCollection.TCollection_ExtendedString: 
        """
        ChangeSeek returns modifiable pointer to Item by Key. Returns NULL is Key was not bound.
        """
    @overload
    def Clear(self,doReleaseMemory : bool=False) -> None: 
        """
        Clear data. If doReleaseMemory is false then the table of buckets is not released and will be reused.

        Clear data and reset allocator
        """
    @overload
    def Clear(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator) -> None: ...
    def Exchange(self,theOther : Resource_DataMapOfAsciiStringExtendedString) -> None: 
        """
        Exchange the content of two maps without re-allocations. Notice that allocators will be swapped as well!
        """
    def Extent(self) -> int: 
        """
        Extent
        """
    @overload
    def Find(self,theKey : OCP.TCollection.TCollection_AsciiString) -> OCP.TCollection.TCollection_ExtendedString: 
        """
        Find returns the Item for Key. Raises if Key was not bound

        Find Item for key with copying.
        """
    @overload
    def Find(self,theKey : OCP.TCollection.TCollection_AsciiString,theValue : OCP.TCollection.TCollection_ExtendedString) -> bool: ...
    def IsBound(self,theKey : OCP.TCollection.TCollection_AsciiString) -> bool: 
        """
        IsBound
        """
    def IsEmpty(self) -> bool: 
        """
        IsEmpty
        """
    def NbBuckets(self) -> int: 
        """
        NbBuckets
        """
    def ReSize(self,N : int) -> None: 
        """
        ReSize
        """
    def Seek(self,theKey : OCP.TCollection.TCollection_AsciiString) -> OCP.TCollection.TCollection_ExtendedString: 
        """
        Seek returns pointer to Item by Key. Returns NULL is Key was not bound.
        """
    def Size(self) -> int: 
        """
        Size
        """
    def Statistics(self,S : io.BytesIO) -> None: 
        """
        Statistics
        """
    def UnBind(self,theKey : OCP.TCollection.TCollection_AsciiString) -> bool: 
        """
        UnBind removes Item Key pair from map
        """
    def __call__(self,theKey : OCP.TCollection.TCollection_AsciiString) -> OCP.TCollection.TCollection_ExtendedString: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theNbBuckets : int,theAllocator : OCP.NCollection.NCollection_BaseAllocator=None) -> None: ...
    @overload
    def __init__(self,theOther : Resource_DataMapOfAsciiStringExtendedString) -> None: ...
    def __iter__(self) -> Iterator[OCP.TCollection.TCollection_ExtendedString]: ...
    def __len__(self) -> int: ...
    pass
class Resource_FormatType():
    """
    List of non ASCII format types which may be converted into the Unicode 16 bits format type. Use the functions provided by the Resource_Unicode class to convert a string from one of these non ASCII format to Unicode, and vice versa.

    Members:

      Resource_FormatType_SJIS

      Resource_FormatType_EUC

      Resource_FormatType_NoConversion

      Resource_FormatType_GB

      Resource_FormatType_UTF8

      Resource_FormatType_SystemLocale

      Resource_FormatType_CP1250

      Resource_FormatType_CP1251

      Resource_FormatType_CP1252

      Resource_FormatType_CP1253

      Resource_FormatType_CP1254

      Resource_FormatType_CP1255

      Resource_FormatType_CP1256

      Resource_FormatType_CP1257

      Resource_FormatType_CP1258

      Resource_FormatType_iso8859_1

      Resource_FormatType_iso8859_2

      Resource_FormatType_iso8859_3

      Resource_FormatType_iso8859_4

      Resource_FormatType_iso8859_5

      Resource_FormatType_iso8859_6

      Resource_FormatType_iso8859_7

      Resource_FormatType_iso8859_8

      Resource_FormatType_iso8859_9

      Resource_FormatType_CP850

      Resource_FormatType_GBK

      Resource_FormatType_Big5

      Resource_FormatType_ANSI

      Resource_SJIS

      Resource_EUC

      Resource_ANSI

      Resource_GB
    """
    def __eq__(self,other : object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __init__(self,value : int) -> None: ...
    def __int__(self) -> int: ...
    def __ne__(self,other : object) -> bool: ...
    def __repr__(self) -> str: ...
    def __setstate__(self,state : int) -> None: ...
    def __str__(self) -> str: ...
    @property
    def name(self) -> None:
        """
        :type: None
        """
    @property
    def value(self) -> int:
        """
        :type: int
        """
    Resource_ANSI: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_NoConversion: 2>
    Resource_EUC: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_EUC: 1>
    Resource_FormatType_ANSI: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_NoConversion: 2>
    Resource_FormatType_Big5: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_Big5: 26>
    Resource_FormatType_CP1250: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_CP1250: 6>
    Resource_FormatType_CP1251: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_CP1251: 7>
    Resource_FormatType_CP1252: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_CP1252: 8>
    Resource_FormatType_CP1253: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_CP1253: 9>
    Resource_FormatType_CP1254: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_CP1254: 10>
    Resource_FormatType_CP1255: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_CP1255: 11>
    Resource_FormatType_CP1256: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_CP1256: 12>
    Resource_FormatType_CP1257: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_CP1257: 13>
    Resource_FormatType_CP1258: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_CP1258: 14>
    Resource_FormatType_CP850: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_CP850: 24>
    Resource_FormatType_EUC: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_EUC: 1>
    Resource_FormatType_GB: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_GB: 3>
    Resource_FormatType_GBK: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_GBK: 25>
    Resource_FormatType_NoConversion: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_NoConversion: 2>
    Resource_FormatType_SJIS: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_SJIS: 0>
    Resource_FormatType_SystemLocale: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_SystemLocale: 5>
    Resource_FormatType_UTF8: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_UTF8: 4>
    Resource_FormatType_iso8859_1: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_iso8859_1: 15>
    Resource_FormatType_iso8859_2: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_iso8859_2: 16>
    Resource_FormatType_iso8859_3: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_iso8859_3: 17>
    Resource_FormatType_iso8859_4: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_iso8859_4: 18>
    Resource_FormatType_iso8859_5: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_iso8859_5: 19>
    Resource_FormatType_iso8859_6: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_iso8859_6: 20>
    Resource_FormatType_iso8859_7: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_iso8859_7: 21>
    Resource_FormatType_iso8859_8: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_iso8859_8: 22>
    Resource_FormatType_iso8859_9: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_iso8859_9: 23>
    Resource_GB: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_GB: 3>
    Resource_SJIS: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_SJIS: 0>
    __entries: dict # value = {'Resource_FormatType_SJIS': (<Resource_FormatType.Resource_FormatType_SJIS: 0>, None), 'Resource_FormatType_EUC': (<Resource_FormatType.Resource_FormatType_EUC: 1>, None), 'Resource_FormatType_NoConversion': (<Resource_FormatType.Resource_FormatType_NoConversion: 2>, None), 'Resource_FormatType_GB': (<Resource_FormatType.Resource_FormatType_GB: 3>, None), 'Resource_FormatType_UTF8': (<Resource_FormatType.Resource_FormatType_UTF8: 4>, None), 'Resource_FormatType_SystemLocale': (<Resource_FormatType.Resource_FormatType_SystemLocale: 5>, None), 'Resource_FormatType_CP1250': (<Resource_FormatType.Resource_FormatType_CP1250: 6>, None), 'Resource_FormatType_CP1251': (<Resource_FormatType.Resource_FormatType_CP1251: 7>, None), 'Resource_FormatType_CP1252': (<Resource_FormatType.Resource_FormatType_CP1252: 8>, None), 'Resource_FormatType_CP1253': (<Resource_FormatType.Resource_FormatType_CP1253: 9>, None), 'Resource_FormatType_CP1254': (<Resource_FormatType.Resource_FormatType_CP1254: 10>, None), 'Resource_FormatType_CP1255': (<Resource_FormatType.Resource_FormatType_CP1255: 11>, None), 'Resource_FormatType_CP1256': (<Resource_FormatType.Resource_FormatType_CP1256: 12>, None), 'Resource_FormatType_CP1257': (<Resource_FormatType.Resource_FormatType_CP1257: 13>, None), 'Resource_FormatType_CP1258': (<Resource_FormatType.Resource_FormatType_CP1258: 14>, None), 'Resource_FormatType_iso8859_1': (<Resource_FormatType.Resource_FormatType_iso8859_1: 15>, None), 'Resource_FormatType_iso8859_2': (<Resource_FormatType.Resource_FormatType_iso8859_2: 16>, None), 'Resource_FormatType_iso8859_3': (<Resource_FormatType.Resource_FormatType_iso8859_3: 17>, None), 'Resource_FormatType_iso8859_4': (<Resource_FormatType.Resource_FormatType_iso8859_4: 18>, None), 'Resource_FormatType_iso8859_5': (<Resource_FormatType.Resource_FormatType_iso8859_5: 19>, None), 'Resource_FormatType_iso8859_6': (<Resource_FormatType.Resource_FormatType_iso8859_6: 20>, None), 'Resource_FormatType_iso8859_7': (<Resource_FormatType.Resource_FormatType_iso8859_7: 21>, None), 'Resource_FormatType_iso8859_8': (<Resource_FormatType.Resource_FormatType_iso8859_8: 22>, None), 'Resource_FormatType_iso8859_9': (<Resource_FormatType.Resource_FormatType_iso8859_9: 23>, None), 'Resource_FormatType_CP850': (<Resource_FormatType.Resource_FormatType_CP850: 24>, None), 'Resource_FormatType_GBK': (<Resource_FormatType.Resource_FormatType_GBK: 25>, None), 'Resource_FormatType_Big5': (<Resource_FormatType.Resource_FormatType_Big5: 26>, None), 'Resource_FormatType_ANSI': (<Resource_FormatType.Resource_FormatType_NoConversion: 2>, None), 'Resource_SJIS': (<Resource_FormatType.Resource_FormatType_SJIS: 0>, None), 'Resource_EUC': (<Resource_FormatType.Resource_FormatType_EUC: 1>, None), 'Resource_ANSI': (<Resource_FormatType.Resource_FormatType_NoConversion: 2>, None), 'Resource_GB': (<Resource_FormatType.Resource_FormatType_GB: 3>, None)}
    __members__: dict # value = {'Resource_FormatType_SJIS': <Resource_FormatType.Resource_FormatType_SJIS: 0>, 'Resource_FormatType_EUC': <Resource_FormatType.Resource_FormatType_EUC: 1>, 'Resource_FormatType_NoConversion': <Resource_FormatType.Resource_FormatType_NoConversion: 2>, 'Resource_FormatType_GB': <Resource_FormatType.Resource_FormatType_GB: 3>, 'Resource_FormatType_UTF8': <Resource_FormatType.Resource_FormatType_UTF8: 4>, 'Resource_FormatType_SystemLocale': <Resource_FormatType.Resource_FormatType_SystemLocale: 5>, 'Resource_FormatType_CP1250': <Resource_FormatType.Resource_FormatType_CP1250: 6>, 'Resource_FormatType_CP1251': <Resource_FormatType.Resource_FormatType_CP1251: 7>, 'Resource_FormatType_CP1252': <Resource_FormatType.Resource_FormatType_CP1252: 8>, 'Resource_FormatType_CP1253': <Resource_FormatType.Resource_FormatType_CP1253: 9>, 'Resource_FormatType_CP1254': <Resource_FormatType.Resource_FormatType_CP1254: 10>, 'Resource_FormatType_CP1255': <Resource_FormatType.Resource_FormatType_CP1255: 11>, 'Resource_FormatType_CP1256': <Resource_FormatType.Resource_FormatType_CP1256: 12>, 'Resource_FormatType_CP1257': <Resource_FormatType.Resource_FormatType_CP1257: 13>, 'Resource_FormatType_CP1258': <Resource_FormatType.Resource_FormatType_CP1258: 14>, 'Resource_FormatType_iso8859_1': <Resource_FormatType.Resource_FormatType_iso8859_1: 15>, 'Resource_FormatType_iso8859_2': <Resource_FormatType.Resource_FormatType_iso8859_2: 16>, 'Resource_FormatType_iso8859_3': <Resource_FormatType.Resource_FormatType_iso8859_3: 17>, 'Resource_FormatType_iso8859_4': <Resource_FormatType.Resource_FormatType_iso8859_4: 18>, 'Resource_FormatType_iso8859_5': <Resource_FormatType.Resource_FormatType_iso8859_5: 19>, 'Resource_FormatType_iso8859_6': <Resource_FormatType.Resource_FormatType_iso8859_6: 20>, 'Resource_FormatType_iso8859_7': <Resource_FormatType.Resource_FormatType_iso8859_7: 21>, 'Resource_FormatType_iso8859_8': <Resource_FormatType.Resource_FormatType_iso8859_8: 22>, 'Resource_FormatType_iso8859_9': <Resource_FormatType.Resource_FormatType_iso8859_9: 23>, 'Resource_FormatType_CP850': <Resource_FormatType.Resource_FormatType_CP850: 24>, 'Resource_FormatType_GBK': <Resource_FormatType.Resource_FormatType_GBK: 25>, 'Resource_FormatType_Big5': <Resource_FormatType.Resource_FormatType_Big5: 26>, 'Resource_FormatType_ANSI': <Resource_FormatType.Resource_FormatType_NoConversion: 2>, 'Resource_SJIS': <Resource_FormatType.Resource_FormatType_SJIS: 0>, 'Resource_EUC': <Resource_FormatType.Resource_FormatType_EUC: 1>, 'Resource_ANSI': <Resource_FormatType.Resource_FormatType_NoConversion: 2>, 'Resource_GB': <Resource_FormatType.Resource_FormatType_GB: 3>}
    pass
class Resource_LexicalCompare():
    def IsLower(self,Left : OCP.TCollection.TCollection_AsciiString,Right : OCP.TCollection.TCollection_AsciiString) -> bool: 
        """
        Returns True if <Left> is lower than <Right>.
        """
    def __init__(self) -> None: ...
    pass
class Resource_Manager(OCP.Standard.Standard_Transient):
    """
    Defines a resource structure and its management methods.Defines a resource structure and its management methods.Defines a resource structure and its management methods.
    """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def ExtValue(self,aResourceName : str) -> str: 
        """
        Gets the value of an ExtString resource according to its instance and its type.
        """
    @overload
    def Find(self,aResource : str) -> bool: 
        """
        returns True if the Resource does exist.

        returns True if the Resource does exist.
        """
    @overload
    def Find(self,theResource : OCP.TCollection.TCollection_AsciiString,theValue : OCP.TCollection.TCollection_AsciiString) -> bool: ...
    def GetMap(self,theRefMap : bool=True) -> Resource_DataMapOfAsciiStringAsciiString: 
        """
        Returns internal Ref or User map with parameters
        """
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    @staticmethod
    def GetResourcePath_s(aPath : OCP.TCollection.TCollection_AsciiString,aName : str,isUserDefaults : bool) -> None: 
        """
        Gets the resource file full path by its name. If corresponding environment variable is not set or file doesn't exist returns empty string.
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    def Integer(self,aResourceName : str) -> int: 
        """
        Gets the value of an integer resource according to its instance and its type.
        """
    def IsInitialized(self) -> bool: 
        """
        Returns true if Resource have been found
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def Real(self,aResourceName : str) -> float: 
        """
        Gets the value of a real resource according to its instance and its type.
        """
    def Save(self) -> bool: 
        """
        Save the user resource structure in the specified file. Creates the file if it does not exist.
        """
    @overload
    def SetResource(self,aResourceName : str,aValue : int) -> None: 
        """
        Sets the new value of an integer resource. If the resource does not exist, it is created.

        Sets the new value of a real resource. If the resource does not exist, it is created.

        Sets the new value of an CString resource. If the resource does not exist, it is created.

        Sets the new value of an ExtString resource. If the resource does not exist, it is created.
        """
    @overload
    def SetResource(self,aResourceName : str,aValue : float) -> None: ...
    @overload
    def SetResource(self,aResourceName : str,aValue : str) -> None: ...
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def Value(self,aResourceName : str) -> str: 
        """
        Gets the value of a CString resource according to its instance and its type.
        """
    @overload
    def __init__(self,aName : str,Verbose : bool=False) -> None: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theName : OCP.TCollection.TCollection_AsciiString,theDefaultsDirectory : OCP.TCollection.TCollection_AsciiString,theUserDefaultsDirectory : OCP.TCollection.TCollection_AsciiString,theIsVerbose : bool=False) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class Resource_Unicode():
    """
    This class provides functions used to convert a non-ASCII C string given in ANSI, EUC, GB or SJIS format, to a Unicode string of extended characters, and vice versa.
    """
    @staticmethod
    def ConvertBig5ToUnicode_s(fromstr : str,tostr : OCP.TCollection.TCollection_ExtendedString) -> bool: 
        """
        Converts non-ASCII CString <fromstr> in Big5 format to Unicode ExtendedString <tostr>.
        """
    @staticmethod
    def ConvertEUCToUnicode_s(fromstr : str,tostr : OCP.TCollection.TCollection_ExtendedString) -> None: 
        """
        Converts non-ASCII CString <fromstr> in EUC format to Unicode ExtendedString <tostr>.
        """
    @staticmethod
    @overload
    def ConvertFormatToUnicode_s(theFromStr : str,theToStr : OCP.TCollection.TCollection_ExtendedString) -> None: 
        """
        Converts the non-ASCII C string (as specified by GetFormat()) to the Unicode string of extended characters.

        Converts the non-ASCII C string in specified format to the Unicode string of extended characters.
        """
    @staticmethod
    @overload
    def ConvertFormatToUnicode_s(theFormat : Resource_FormatType,theFromStr : str,theToStr : OCP.TCollection.TCollection_ExtendedString) -> None: ...
    @staticmethod
    def ConvertGBKToUnicode_s(fromstr : str,tostr : OCP.TCollection.TCollection_ExtendedString) -> bool: 
        """
        Converts non-ASCII CString <fromstr> in GBK format to Unicode ExtendedString <tostr>.
        """
    @staticmethod
    def ConvertGBToUnicode_s(fromstr : str,tostr : OCP.TCollection.TCollection_ExtendedString) -> None: 
        """
        Converts non-ASCII CString <fromstr> in GB format to Unicode ExtendedString <tostr>.
        """
    @staticmethod
    def ConvertSJISToUnicode_s(fromstr : str,tostr : OCP.TCollection.TCollection_ExtendedString) -> None: 
        """
        Converts non-ASCII CString <fromstr> in SJIS format to Unicode ExtendedString <tostr>.
        """
    @staticmethod
    def GetFormat_s() -> Resource_FormatType: 
        """
        Returns the current conversion format (either ANSI, EUC, GB or SJIS). The current converting format must be defined in advance with the SetFormat function.
        """
    @staticmethod
    def ReadFormat_s() -> None: 
        """
        Reads converting format from resource "FormatType" in Resource Manager "CharSet"
        """
    @staticmethod
    def SetFormat_s(typecode : Resource_FormatType) -> None: 
        """
        Defines the current conversion format as typecode. This conversion format will then be used by the functions ConvertFormatToUnicode and ConvertUnicodeToFormat to convert the strings.
        """
    def __init__(self) -> None: ...
    pass
Resource_ANSI: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_NoConversion: 2>
Resource_EUC: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_EUC: 1>
Resource_FormatType_ANSI: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_NoConversion: 2>
Resource_FormatType_Big5: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_Big5: 26>
Resource_FormatType_CP1250: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_CP1250: 6>
Resource_FormatType_CP1251: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_CP1251: 7>
Resource_FormatType_CP1252: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_CP1252: 8>
Resource_FormatType_CP1253: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_CP1253: 9>
Resource_FormatType_CP1254: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_CP1254: 10>
Resource_FormatType_CP1255: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_CP1255: 11>
Resource_FormatType_CP1256: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_CP1256: 12>
Resource_FormatType_CP1257: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_CP1257: 13>
Resource_FormatType_CP1258: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_CP1258: 14>
Resource_FormatType_CP850: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_CP850: 24>
Resource_FormatType_EUC: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_EUC: 1>
Resource_FormatType_GB: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_GB: 3>
Resource_FormatType_GBK: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_GBK: 25>
Resource_FormatType_NoConversion: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_NoConversion: 2>
Resource_FormatType_SJIS: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_SJIS: 0>
Resource_FormatType_SystemLocale: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_SystemLocale: 5>
Resource_FormatType_UTF8: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_UTF8: 4>
Resource_FormatType_iso8859_1: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_iso8859_1: 15>
Resource_FormatType_iso8859_2: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_iso8859_2: 16>
Resource_FormatType_iso8859_3: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_iso8859_3: 17>
Resource_FormatType_iso8859_4: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_iso8859_4: 18>
Resource_FormatType_iso8859_5: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_iso8859_5: 19>
Resource_FormatType_iso8859_6: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_iso8859_6: 20>
Resource_FormatType_iso8859_7: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_iso8859_7: 21>
Resource_FormatType_iso8859_8: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_iso8859_8: 22>
Resource_FormatType_iso8859_9: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_iso8859_9: 23>
Resource_GB: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_GB: 3>
Resource_SJIS: OCP.Resource.Resource_FormatType # value = <Resource_FormatType.Resource_FormatType_SJIS: 0>



import OCP.CPnts
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.math
import OCP.gp
import OCP.Adaptor2d
import OCP.Adaptor3d
__all__  = [
"CPnts_AbscissaPoint",
"CPnts_MyGaussFunction",
"CPnts_MyRootFunction",
"CPnts_UniformDeflection"
]
class CPnts_AbscissaPoint():
    """
    the algorithm computes a point on a curve at a given distance from another point on the curve
    """
    def AdvPerform(self,Abscissa : float,U0 : float,Ui : float,Resolution : float) -> None: 
        """
        Computes the point at the distance <Abscissa> of the curve; performs more appropriate tolerance management; to use this method in right way it is necessary to call empty constructor. then call method Init with Tolerance = Resolution, then call AdvPermorm. U0 is the parameter of the point from which the distance is measured and Ui is the starting value for the iterative process (should be close to the final solution).
        """
    @overload
    def Init(self,C : OCP.Adaptor3d.Adaptor3d_Curve) -> None: 
        """
        Initializes the resolution function with <C>.

        Initializes the resolution function with <C>.

        Initializes the resolution function with <C>.

        Initializes the resolution function with <C>.

        Initializes the resolution function with <C> between U1 and U2.

        Initializes the resolution function with <C> between U1 and U2.

        Initializes the resolution function with <C> between U1 and U2.

        Initializes the resolution function with <C> between U1 and U2.
        """
    @overload
    def Init(self,C : OCP.Adaptor2d.Adaptor2d_Curve2d) -> None: ...
    @overload
    def Init(self,C : OCP.Adaptor3d.Adaptor3d_Curve,Tol : float) -> None: ...
    @overload
    def Init(self,C : OCP.Adaptor2d.Adaptor2d_Curve2d,Tol : float) -> None: ...
    @overload
    def Init(self,C : OCP.Adaptor3d.Adaptor3d_Curve,U1 : float,U2 : float) -> None: ...
    @overload
    def Init(self,C : OCP.Adaptor2d.Adaptor2d_Curve2d,U1 : float,U2 : float) -> None: ...
    @overload
    def Init(self,C : OCP.Adaptor3d.Adaptor3d_Curve,U1 : float,U2 : float,Tol : float) -> None: ...
    @overload
    def Init(self,C : OCP.Adaptor2d.Adaptor2d_Curve2d,U1 : float,U2 : float,Tol : float) -> None: ...
    def IsDone(self) -> bool: 
        """
        True if the computation was successful, False otherwise.

        True if the computation was successful, False otherwise.
        """
    @staticmethod
    @overload
    def Length_s(C : OCP.Adaptor3d.Adaptor3d_Curve) -> float: 
        """
        Computes the length of the Curve <C>.

        Computes the length of the Curve <C>.

        Computes the length of the Curve <C> with the given tolerance.

        Computes the length of the Curve <C> with the given tolerance.

        Computes the length of the Curve <C> between <U1> and <U2>.

        Computes the length of the Curve <C> between <U1> and <U2>.

        Computes the length of the Curve <C> between <U1> and <U2> with the given tolerance.

        Computes the length of the Curve <C> between <U1> and <U2> with the given tolerance. creation of a indefinite AbscissaPoint.
        """
    @staticmethod
    @overload
    def Length_s(C : OCP.Adaptor2d.Adaptor2d_Curve2d) -> float: ...
    @staticmethod
    @overload
    def Length_s(C : OCP.Adaptor3d.Adaptor3d_Curve,Tol : float) -> float: ...
    @staticmethod
    @overload
    def Length_s(C : OCP.Adaptor2d.Adaptor2d_Curve2d,Tol : float) -> float: ...
    @staticmethod
    @overload
    def Length_s(C : OCP.Adaptor3d.Adaptor3d_Curve,U1 : float,U2 : float) -> float: ...
    @staticmethod
    @overload
    def Length_s(C : OCP.Adaptor2d.Adaptor2d_Curve2d,U1 : float,U2 : float) -> float: ...
    @staticmethod
    @overload
    def Length_s(C : OCP.Adaptor3d.Adaptor3d_Curve,U1 : float,U2 : float,Tol : float) -> float: ...
    @staticmethod
    @overload
    def Length_s(C : OCP.Adaptor2d.Adaptor2d_Curve2d,U1 : float,U2 : float,Tol : float) -> float: ...
    def Parameter(self) -> float: 
        """
        Returns the parameter of the solution.

        Returns the parameter of the solution.
        """
    @overload
    def Perform(self,Abscissa : float,U0 : float,Resolution : float) -> None: 
        """
        Computes the point at the distance <Abscissa> of the curve. U0 is the parameter of the point from which the distance is measured.

        Computes the point at the distance <Abscissa> of the curve. U0 is the parameter of the point from which the distance is measured and Ui is the starting value for the iterative process (should be close to the final solution).
        """
    @overload
    def Perform(self,Abscissa : float,U0 : float,Ui : float,Resolution : float) -> None: ...
    def SetParameter(self,P : float) -> None: 
        """
        Enforce the solution, used by GCPnts.

        Enforce the solution, used by GCPnts.
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,C : OCP.Adaptor3d.Adaptor3d_Curve,Abscissa : float,U0 : float,Resolution : float) -> None: ...
    @overload
    def __init__(self,C : OCP.Adaptor2d.Adaptor2d_Curve2d,Abscissa : float,U0 : float,Resolution : float) -> None: ...
    @overload
    def __init__(self,C : OCP.Adaptor3d.Adaptor3d_Curve,Abscissa : float,U0 : float,Ui : float,Resolution : float) -> None: ...
    @overload
    def __init__(self,C : OCP.Adaptor2d.Adaptor2d_Curve2d,Abscissa : float,U0 : float,Ui : float,Resolution : float) -> None: ...
    pass
class CPnts_MyGaussFunction(OCP.math.math_Function):
    """
    for implementation, compute values for Gauss
    """
    def GetStateNumber(self) -> int: 
        """
        returns the state of the function corresponding to the latest call of any methods associated with the function. This function is called by each of the algorithms described later which defined the function Integer Algorithm::StateNumber(). The algorithm has the responsibility to call this function when it has found a solution (i.e. a root or a minimum) and has to maintain the association between the solution found and this StateNumber. Byu default, this method returns 0 (which means for the algorithm: no state has been saved). It is the responsibility of the programmer to decide if he needs to save the current state of the function and to return an Integer that allows retrieval of the state.
        """
    def Value(self,X : float,F : float) -> bool: ...
    def __init__(self) -> None: ...
    pass
class CPnts_MyRootFunction(OCP.math.math_FunctionWithDerivative, OCP.math.math_Function):
    """
    Implements a function for the Newton algorithm to find the solution of Integral(F) = L (compute Length and Derivative of the curve for Newton)
    """
    def Derivative(self,X : float,Df : float) -> bool: 
        """
        This is F(X,D)
        """
    def GetStateNumber(self) -> int: 
        """
        returns the state of the function corresponding to the latest call of any methods associated with the function. This function is called by each of the algorithms described later which defined the function Integer Algorithm::StateNumber(). The algorithm has the responsibility to call this function when it has found a solution (i.e. a root or a minimum) and has to maintain the association between the solution found and this StateNumber. Byu default, this method returns 0 (which means for the algorithm: no state has been saved). It is the responsibility of the programmer to decide if he needs to save the current state of the function and to return an Integer that allows retrieval of the state.
        """
    @overload
    def Init(self,X0 : float,L : float) -> None: 
        """
        We want to solve Integral(X0,X,F(X,D)) = L

        We want to solve Integral(X0,X,F(X,D)) = L with given tolerance
        """
    @overload
    def Init(self,X0 : float,L : float,Tol : float) -> None: ...
    def Value(self,X : float,F : float) -> bool: 
        """
        This is Integral(X0,X,F(X,D)) - L
        """
    def Values(self,X : float,F : float,Df : float) -> bool: ...
    def __init__(self) -> None: ...
    pass
class CPnts_UniformDeflection():
    """
    This class defines an algorithm to create a set of points (with a given chordal deviation) at the positions of constant deflection of a given parametrized curve or a trimmed circle. The continuity of the curve must be at least C2.
    """
    @overload
    def Initialize(self,C : OCP.Adaptor3d.Adaptor3d_Curve,Deflection : float,Resolution : float,WithControl : bool) -> None: 
        """
        Initialize the algorithms with <C>, <Deflection>, <UStep>, <Resolution> and <WithControl>

        Initialize the algorithms with <C>, <Deflection>, <UStep>, <Resolution> and <WithControl>

        Initialize the algorithms with <C>, <Deflection>, <UStep>, <U1>, <U2> and <WithControl>

        Initialize the algorithms with <C>, <Deflection>, <UStep>, <U1>, <U2> and <WithControl>
        """
    @overload
    def Initialize(self,C : OCP.Adaptor2d.Adaptor2d_Curve2d,Deflection : float,Resolution : float,WithControl : bool) -> None: ...
    @overload
    def Initialize(self,C : OCP.Adaptor3d.Adaptor3d_Curve,Deflection : float,U1 : float,U2 : float,Resolution : float,WithControl : bool) -> None: ...
    @overload
    def Initialize(self,C : OCP.Adaptor2d.Adaptor2d_Curve2d,Deflection : float,U1 : float,U2 : float,Resolution : float,WithControl : bool) -> None: ...
    def IsAllDone(self) -> bool: 
        """
        To know if all the calculus were done successfully (ie all the points have been computed). The calculus can fail if the Curve is not C1 in the considered domain. Returns True if the calculus was successful.

        To know if all the calculus were done successfully (ie all the points have been computed). The calculus can fail if the Curve is not C1 in the considered domain. Returns True if the calculus was successful.
        """
    def More(self) -> bool: 
        """
        returns True if it exists a next Point.
        """
    def Next(self) -> None: 
        """
        go to the next Point.

        go to the next Point.
        """
    def Point(self) -> OCP.gp.gp_Pnt: 
        """
        return the computed parameter

        return the computed parameter
        """
    def Value(self) -> float: 
        """
        return the computed parameter

        return the computed parameter
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,C : OCP.Adaptor3d.Adaptor3d_Curve,Deflection : float,Resolution : float,WithControl : bool) -> None: ...
    @overload
    def __init__(self,C : OCP.Adaptor2d.Adaptor2d_Curve2d,Deflection : float,Resolution : float,WithControl : bool) -> None: ...
    @overload
    def __init__(self,C : OCP.Adaptor3d.Adaptor3d_Curve,Deflection : float,U1 : float,U2 : float,Resolution : float,WithControl : bool) -> None: ...
    @overload
    def __init__(self,C : OCP.Adaptor2d.Adaptor2d_Curve2d,Deflection : float,U1 : float,U2 : float,Resolution : float,WithControl : bool) -> None: ...
    pass
